#
# spec file for package mozo
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 1.28

Name:           mozo
Version:        1.28.0
Release:        1.4
Summary:        MATE Desktop menu editor
License:        LGPL-2.1-or-later
URL:            https://mate-desktop.org/
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(libmate-menu) >= %{_version}
BuildRequires:  pkgconfig(pygobject-3.0)
Requires:       mate-menus >= %{_version}
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Recommends:     %{name}-lang
# mate-menu-editor was last used in openSUSE 13.1.
Provides:       mate-menu-editor = %{version}
Obsoletes:      mate-menu-editor < %{version}
Obsoletes:      mate-menu-editor-lang < %{version}
BuildArch:      noarch

%description
This package provides Mozo, a menu editor for the MATE Desktop,
using the freedesktop.org menu specification.

%lang_package

%prep
%setup -q

%build
NOCONFIGURE=1 mate-autogen
%configure
%make_build

%install
%make_install

%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{python_sitelib}/
%suse_update_desktop_file %{name}

%files
%license COPYING
%doc AUTHORS NEWS README
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{python3_sitelib}/Mozo/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*
%{_mandir}/man?/%{name}.?%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Mon Mar 25 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.28.0
  * Update translations
* Mon Nov 21 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.2
  * Translations update
  * meson build: drop desktop-file argument
  * only require gtk version 3.12 instead of 3.24
* Sat Nov 20 2021 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.26.1:
  * mozo-ui: Fix a typo in the button label.
  * Make the collection menu item removeable.
  * Fix adding and removing seperator item.
  * Update translations.
* Thu Aug 12 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * Update Translations
  * Update copyright to 2021
  * Rewrite mozo.ui from scratch
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.24.1:
  * Translations update
  * i18n: Do not collect the translation for Icon
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0 (changes since 1.23.0):
  * desktop file: Add missing hints for translators.
  * Sets the required version for gettext (0.19.8).
  * Add Undo and Redo buttons.
  * moveItem: Remove redundant code, add missing check for move
    mode when merging entries.
  * Change DragAction to MOVE.
  * undo/redo: Handle missing files.
  * Fix item drag & drop creating copies, fix undo, redo and a
    crash when refreshing.
  * Update translations.
- Drop support for old openSUSE versions.
* Thu Jul 18 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.23.0:
  * Translations update
  * Fix DeprecationWarning ABCs from 'collections'
  * Fix DeprecationWarning: cgi.escape is deprecated
  * Change url project's website
  * use meson to build
  * Migrate from intltool to gettext
  * Fix drag and drop of .desktop file
- remove patch:
  * mozo-python-3.4.patch: we don't support Leap 42.3, which has no
    python 3.4, anymore
* Sun May 12 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.22.1:
  * Fix creating new menus and items.
  * Fix moving a menu corrupting the menu.
  * Update translations.
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * Drop acinclude.m4 which is not needed anymore.
  * Support new mate-menus api.
  * Remove libdir from Mozo/config.py.
  * Re-indent python code.
  * Fix menu entry can not move.
  * Update translations.
- Add mozo-python-3.4.patch: Restore Python 3.4 support.
- Remove mozo-1.20.1-remove-libdir-from-config.patch: fixed
  upstream.
* Wed Dec 26 2018 sor.alexei@meowr.ru
- Update to version 1.20.2:
  * Disable deprecation warnings for distcheck.
  * Update translations.
* Tue Oct  2 2018 antoine.belvire@opensuse.org
- Add mozo-1.20.1-remove-libdir-from-config.patch (picked from
  upstream): Make build reproducible (boo#1110032).
* Fri Jun 22 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * Update translations.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Add Properties and Delete buttons.
  * Fix several drag-and-drop issues.
  * Fix a crash when .desktop file has slash in the name.
  * Some more fixes and cleanups.
  * Update translations.
- Remove mozo-gtk3.10.patch.
* Wed Aug 24 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * Fix a crash and erasing of the menu file when processing
    non-ASCII characters.
  * Fix a crash on invalid XML file.
  * Always encode with UTF-8 before writing the XML file.
  * Update translations.
* Wed May  4 2016 sor.alexei@meowr.ru
- Add a missing python-gobject-Gdk dependency.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Update translations.
  * Fix Changelog generation.
* Sat Mar  5 2016 sor.alexei@meowr.ru
- Update to version 1.13.1:
  * Move to GTK+3 and GObject Introspection, drop old
    PyGTK+-related code.
- Add mozo-gtk3.10.patch: add support for Gtk 3.10 (SLE 12 and
  openSUSE 13.1).
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to version 1.13.0.
* Mon Jan 11 2016 sor.alexei@meowr.ru
- Add missing mate-menus dependency.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0:
  * Enable startup notification.
  * Add silent rules.
  * Some bugfixes.
* Wed Jul 23 2014 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Fix wrong highlighting while moving menu items when separators
    are present.
  * Remove deprecated GTK properties.
  * Fix help link.
* Tue May 20 2014 sor.alexei@meowr.ru
- Update to 1.10.0:
  * Update translations.
- Spec cleanup.
* Mon Mar 10 2014 cfarrell@suse.com
- license update: LGPL-2.1+
  No indication of any GPL-2.0+ licensed files in the package. COPYING is
  LGPL-2.1+
* Mon Mar 10 2014 p.drouand@gmail.com
- Add a Obsoletes tag to avoid conflicts with mate-menu-editor
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Sat Feb 15 2014 p.drouand@gmail.com
- Initial release (version 1.7.0)
